==> jc-1.4.0.tar.gz: polyglot/visit/FlattenVisitor.h <==
// public class polyglot.visit.FlattenVisitor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3a8a58ab836c0c23 polyglot_visit_FlattenVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_FlattenVisitor_H_
#define _JC_polyglot_visit_FlattenVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_LinkedList$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlattenVisitor$sub_refs	_jc_polyglot_visit_FlattenVisitor$sub_refs;
typedef struct _jc_polyglot_visit_FlattenVisitor$sub_nonrefs	_jc_polyglot_visit_FlattenVisitor$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlattenVisitor$refs	_jc_polyglot_visit_FlattenVisitor$refs;
typedef struct _jc_polyglot_visit_FlattenVisitor$nonrefs	_jc_polyglot_visit_FlattenVisitor$nonrefs;
typedef struct _jc_polyglot_visit_FlattenVisitor$object	_jc_polyglot_visit_FlattenVisitor$object;

typedef struct _jc_polyglot_visit_FlattenVisitor$fields_struct	_jc_polyglot_visit_FlattenVisitor$fields_struct;
typedef const struct _jc_polyglot_visit_FlattenVisitor$vmethods	_jc_polyglot_visit_FlattenVisitor$vmethods;
typedef const struct _jc_polyglot_visit_FlattenVisitor$vtable	_jc_polyglot_visit_FlattenVisitor$vtable;
typedef const struct _jc_polyglot_visit_FlattenVisitor$vtype	_jc_polyglot_visit_FlattenVisitor$vtype;

// Class fields structure
struct _jc_polyglot_visit_FlattenVisitor$fields_struct {
	jint	count;
};
extern _jc_polyglot_visit_FlattenVisitor$fields_struct _jc_polyglot_visit_FlattenVisitor$class_fields;

// Constructors
extern void _jc_polyglot_visit_FlattenVisitor$method$_init$5f44ce139b44c505(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_FlattenVisitor$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_visit_FlattenVisitor$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
extern struct _jc_object *_jc_polyglot_visit_FlattenVisitor$method$override$1e05b257002785f7(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlattenVisitor$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_FlattenVisitor$method_info$leave$cf18a0cab654af63;
extern _jc_method _jc_polyglot_visit_FlattenVisitor$method_info$override$1e05b257002785f7;

// Static methods
extern void _jc_polyglot_visit_FlattenVisitor$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlattenVisitor$method$newID$87051e1cf288e0d9(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_visit_FlattenVisitor$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
	struct _jc_object	*(*override$1e05b257002785f7)(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_visit_FlattenVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_FlattenVisitor$vmethods	polyglot_visit_FlattenVisitor;
};

// Vtype
struct _jc_polyglot_visit_FlattenVisitor$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlattenVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlattenVisitor$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*nf;
	struct _jc_java_util_LinkedList$object	*stack;
	struct _jc_object	*noFlatten;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlattenVisitor$refs {
    _jc_polyglot_visit_FlattenVisitor$sub_refs	polyglot_visit_FlattenVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlattenVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlattenVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_FlattenVisitor$sub_nonrefs	polyglot_visit_FlattenVisitor;
};

// Object instance structure
struct _jc_polyglot_visit_FlattenVisitor$object {
	_jc_polyglot_visit_FlattenVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlattenVisitor$vtype	*vtype;
	_jc_polyglot_visit_FlattenVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlattenVisitor$vtype _jc_polyglot_visit_FlattenVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlattenVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlattenVisitor$class_object;

#endif	/* _JC_polyglot_visit_FlattenVisitor_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/FlattenVisitor.h <==
// public class polyglot.visit.FlattenVisitor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3a8a58ab836c0c23 polyglot_visit_FlattenVisitor
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_polyglot_visit_FlattenVisitor_H_
#define _JC_polyglot_visit_FlattenVisitor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_LinkedList$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_NodeFactory$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlattenVisitor$sub_refs	_jc_polyglot_visit_FlattenVisitor$sub_refs;
typedef struct _jc_polyglot_visit_FlattenVisitor$sub_nonrefs	_jc_polyglot_visit_FlattenVisitor$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlattenVisitor$refs	_jc_polyglot_visit_FlattenVisitor$refs;
typedef struct _jc_polyglot_visit_FlattenVisitor$nonrefs	_jc_polyglot_visit_FlattenVisitor$nonrefs;
typedef struct _jc_polyglot_visit_FlattenVisitor$object	_jc_polyglot_visit_FlattenVisitor$object;

typedef struct _jc_polyglot_visit_FlattenVisitor$fields_struct	_jc_polyglot_visit_FlattenVisitor$fields_struct;
typedef const struct _jc_polyglot_visit_FlattenVisitor$vmethods	_jc_polyglot_visit_FlattenVisitor$vmethods;
typedef const struct _jc_polyglot_visit_FlattenVisitor$vtable	_jc_polyglot_visit_FlattenVisitor$vtable;
typedef const struct _jc_polyglot_visit_FlattenVisitor$vtype	_jc_polyglot_visit_FlattenVisitor$vtype;

// Class fields structure
struct _jc_polyglot_visit_FlattenVisitor$fields_struct {
	jint	count;
};
extern _jc_polyglot_visit_FlattenVisitor$fields_struct _jc_polyglot_visit_FlattenVisitor$class_fields;

// Constructors
extern void _jc_polyglot_visit_FlattenVisitor$method$_init$5f44ce139b44c505(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_visit_FlattenVisitor$method$enter$a8ce2b9db363b202(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_FlattenVisitor$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_visit_FlattenVisitor$method$override$1e05b257002785f7(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlattenVisitor$method_info$enter$a8ce2b9db363b202;
extern _jc_method _jc_polyglot_visit_FlattenVisitor$method_info$leave$cf18a0cab654af63;
extern _jc_method _jc_polyglot_visit_FlattenVisitor$method_info$override$1e05b257002785f7;

// Static methods
extern void _jc_polyglot_visit_FlattenVisitor$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_FlattenVisitor$method$newID$87051e1cf288e0d9(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_visit_FlattenVisitor$vmethods {
	struct _jc_polyglot_visit_NodeVisitor$object	*(*enter$a8ce2b9db363b202)(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*override$1e05b257002785f7)(_jc_env *, struct _jc_polyglot_visit_FlattenVisitor$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_FlattenVisitor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_polyglot_visit_FlattenVisitor$vmethods	polyglot_visit_FlattenVisitor;
};

// Vtype
struct _jc_polyglot_visit_FlattenVisitor$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlattenVisitor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlattenVisitor$sub_refs {
	struct _jc_object	*ts;
	struct _jc_object	*nf;
	struct _jc_java_util_LinkedList$object	*stack;
	struct _jc_object	*noFlatten;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlattenVisitor$refs {
    _jc_polyglot_visit_FlattenVisitor$sub_refs	polyglot_visit_FlattenVisitor;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlattenVisitor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlattenVisitor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_polyglot_visit_FlattenVisitor$sub_nonrefs	polyglot_visit_FlattenVisitor;
};

// Object instance structure
struct _jc_polyglot_visit_FlattenVisitor$object {
	_jc_polyglot_visit_FlattenVisitor$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlattenVisitor$vtype	*vtype;
	_jc_polyglot_visit_FlattenVisitor$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlattenVisitor$vtype _jc_polyglot_visit_FlattenVisitor$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlattenVisitor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlattenVisitor$class_object;

#endif	/* _JC_polyglot_visit_FlattenVisitor_H_ */
